summaryrefslogtreecommitdiffstats
path: root/kaddressbook/xxport/vcard_xxport.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kaddressbook/xxport/vcard_xxport.cpp')
-rw-r--r--kaddressbook/xxport/vcard_xxport.cpp36
1 files changed, 18 insertions, 18 deletions
diff --git a/kaddressbook/xxport/vcard_xxport.cpp b/kaddressbook/xxport/vcard_xxport.cpp
index 1e5d7ee94..e752b9057 100644
--- a/kaddressbook/xxport/vcard_xxport.cpp
+++ b/kaddressbook/xxport/vcard_xxport.cpp
@@ -25,7 +25,7 @@
#include <tqfile.h>
#include <tqfont.h>
#include <tqlabel.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqpushbutton.h>
#include <kabc/vcardconverter.h>
@@ -237,12 +237,12 @@ KABC::AddresseeList VCardXXPort::importContacts( const TQString& ) const
TQString vCardText;
// With version 3.0, vCards are encoded with UTF-8 by default. Otherwise, use fromLatin1()
// and hope that are fields are encoded correctly.
- if ( TQString::fromLatin1( rawData ).lower().contains( "version:3.0" ) ) {
+ if ( TQString::tqfromLatin1( rawData ).lower().contains( "version:3.0" ) ) {
vCardText = TQString::fromUtf8( rawData );
} else {
- vCardText = TQString::fromLatin1( rawData );
+ vCardText = TQString::tqfromLatin1( rawData );
}
addrList += parseVCard( vCardText );
}
@@ -250,15 +250,15 @@ KABC::AddresseeList VCardXXPort::importContacts( const TQString& ) const
KIO::NetAccess::removeTempFile( fileName );
} else {
TQString text = i18n( "<qt>When trying to read the vCard, there was an error opening the file '%1': %2</qt>" );
- text = text.arg( (*it).url() );
- text = text.arg( kapp->translate( "TQFile",
+ text = text.tqarg( (*it).url() );
+ text = text.tqarg( kapp->translate( "TQFile",
TQString(file.errorString()).latin1() ) );
KMessageBox::error( parentWidget(), text, caption );
anyFailures = true;
}
} else {
TQString text = i18n( "<qt>Unable to access vCard: %1</qt>" );
- text = text.arg( KIO::NetAccess::lastErrorString() );
+ text = text.tqarg( KIO::NetAccess::lastErrorString() );
KMessageBox::error( parentWidget(), text, caption );
anyFailures = true;
}
@@ -293,7 +293,7 @@ KABC::AddresseeList VCardXXPort::parseVCard( const TQByteArray &data ) const
bool VCardXXPort::doExport( const KURL &url, const TQByteArray &data )
{
if( TQFileInfo(url.path()).exists() ) {
- if(KMessageBox::questionYesNo( parentWidget(), i18n("Do you want to overwrite file \"%1\"").arg( url.path()) ) == KMessageBox::No)
+ if(KMessageBox::questionYesNo( parentWidget(), i18n("Do you want to overwrite file \"%1\"").tqarg( url.path()) ) == KMessageBox::No)
return false;
}
KTempFile tmpFile;
@@ -315,7 +315,7 @@ KABC::AddresseeList VCardXXPort::parseVCard( const TQString &data ) const
bool VCardXXPort::doExport( const KURL &url, const TQString &data )
{
if( TQFileInfo(url.path()).exists() ) {
- if(KMessageBox::questionYesNo( parentWidget(), i18n("Do you want to overwrite file \"%1\"").arg( url.path()) ) == KMessageBox::No)
+ if(KMessageBox::questionYesNo( parentWidget(), i18n("Do you want to overwrite file \"%1\"").tqarg( url.path()) ) == KMessageBox::No)
return false;
}
KTempFile tmpFile;
@@ -471,18 +471,18 @@ VCardViewerDialog::VCardViewerDialog( const KABC::Addressee::List &list,
mContacts( list )
{
TQFrame *page = plainPage();
- TQVBoxLayout *layout = new TQVBoxLayout( page, marginHint(), spacingHint() );
+ TQVBoxLayout *tqlayout = new TQVBoxLayout( page, marginHint(), spacingHint() );
TQLabel *label = new TQLabel( i18n( "Do you want to import this contact in your address book?" ), page );
TQFont font = label->font();
font.setBold( true );
label->setFont( font );
- layout->addWidget( label );
+ tqlayout->addWidget( label );
mView = new KPIM::AddresseeView( page );
mView->enableLinks( 0 );
mView->setVScrollBarMode( TQScrollView::Auto );
- layout->addWidget( mView );
+ tqlayout->addWidget( mView );
setButtonText( Apply, i18n( "Import All..." ) );
@@ -544,22 +544,22 @@ VCardExportSelectionDialog::VCardExportSelectionDialog( TQWidget *parent,
{
TQFrame *page = plainPage();
- TQVBoxLayout *layout = new TQVBoxLayout( page, marginHint(), spacingHint() );
+ TQVBoxLayout *tqlayout = new TQVBoxLayout( page, marginHint(), spacingHint() );
TQLabel *label = new TQLabel( i18n( "Select the fields which shall be exported in the vCard." ), page );
- layout->addWidget( label );
+ tqlayout->addWidget( label );
mPrivateBox = new TQCheckBox( i18n( "Private fields" ), page );
- layout->addWidget( mPrivateBox );
+ tqlayout->addWidget( mPrivateBox );
mBusinessBox = new TQCheckBox( i18n( "Business fields" ), page );
- layout->addWidget( mBusinessBox );
+ tqlayout->addWidget( mBusinessBox );
mOtherBox = new TQCheckBox( i18n( "Other fields" ), page );
- layout->addWidget( mOtherBox );
+ tqlayout->addWidget( mOtherBox );
mEncryptionKeys = new TQCheckBox( i18n( "Encryption keys" ), page );
- layout->addWidget( mEncryptionKeys );
+ tqlayout->addWidget( mEncryptionKeys );
KConfig config( "kaddressbookrc" );
config.setGroup( "XXPortVCard" );
@@ -237,12 +237,12 @@ KABC::AddresseeList VCardXXPort::importContacts( const TQString& ) const
TQString vCardText;
- // With version 3.0, vCards are encoded with UTF-8 by default. Otherwise, use fromLatin1()
+ // With version 3.0, vCards are encoded with UTF-8 by default. Otherwise, use tqfromLatin1()
// and hope that are fields are encoded correctly.